<?php 

defined('ABSPATH') or die("No direct script access!");

/*
* Post Type settings area
*/
class Qcld_Express_Performance_Area_Controller {
    
    function __construct(){

        add_action( 'admin_menu', array($this,'qcld_express_performance_admin_menu') );
        add_action( 'admin_init', array($this, 'qcld_express_performance_register_plugin_settings') );

    }

    public function qcld_express_performance_admin_menu(){

        add_submenu_page( 'express-shop', 
                        __('Performance','express-shop-pro'), 
                        __('Performance','express-shop-pro'), 
                        'manage_options',
                        'qcld-express-performance', 
                        array($this, 'qcld_express_performance_settings_page') );
        
    }
    
    public function qcld_express_performance_register_plugin_settings(){    


        $args = array(
            'type' => 'string', 
            'sanitize_callback' => 'sanitize_text_field',
            'default' => NULL,
        );  

        $args_email = array(
            'type' => 'string', 
            'sanitize_callback' => 'sanitize_email',
            'default' => NULL,
        );      
        
        register_setting( 'qc-express-performance-settings-group', 'qcld_express_defer_load_js', $args );

        register_setting( 'qc-express-performance-settings-group', 'qcld_express_optimize_js_code', $args );
        register_setting( 'qc-express-performance-settings-group', 'qcld_express_optimize_css_code', $args );

        register_setting( 'qc-express-performance-settings-group', 'qcld_express_enable_cache', $args );
        register_setting( 'qc-express-performance-settings-group', 'qcld_express_regenerate_cache_time', $args );

        
    }
    
    
    public function qcld_express_performance_settings_page(){
        
    ?>
    <style type="text/css">
        .form-table-performance{
            margin-top: 15px;
            background: #fff;
            border-radius: 2px;
            box-shadow: 0 0 0 1px rgb(0 0 0 / 7%), 0 1px 1px rgb(0 0 0 / 4%);
        }
        .form-table-performance tr{
            border-bottom: 1px solid #eee;
            display: block;
        }
        .form-table-performance th{
            padding: 20px 10px 20px 20px;
        }
        .form-table-performance td{
            padding: 20px 10px 20px 20px;
        }
    </style>
    <div class="wrap">
        <h1><?php esc_html_e('Performance Settings','express-shop-pro') ?></h1>
        <p><?php esc_html_e('Change for Performance','express-shop-pro') ?></p>
        <form method="post" action="options.php">
            <?php settings_fields( 'qc-express-performance-settings-group' ); ?>
            <?php do_settings_sections( 'qc-express-performance-settings-group' ); ?>
            <div >
                <table class="form-table form-table-performance" >
                    <tr valign="top">
                        <th scope="row"><?php esc_html_e('Defer/delay loading Javascript files','express-shop-pro') ?></th>
                        <td>
                            <input type="checkbox" name="qcld_express_defer_load_js" size="100" value="<?php echo (get_option('qcld_express_defer_load_js')!=''? esc_attr( get_option('qcld_express_defer_load_js')) : '1' ); ?>" <?php echo (get_option('qcld_express_defer_load_js') == '' ? esc_attr( get_option('qcld_express_defer_load_js')): esc_attr( 'checked="checked"' )); ?>  />  
                            <i><?php esc_html_e(' This can help improve PageSpeed Score. No need to enable this if your server supports HTTP2.','express-shop-pro') ?></i>                           
                        </td>
                    </tr>
                    
                    <tr valign="top" style="border-bottom: 1px solid #eee;display: block;">
                        <th scope="row"><?php esc_html_e('Minify JavaScript Files','express-shop-pro') ?></th>
                        <td>
                            <input type="checkbox" name="qcld_express_optimize_js_code" size="100" value="<?php echo (get_option('qcld_express_optimize_js_code')!=''? esc_attr( get_option('qcld_express_optimize_js_code')) : '1' ); ?>" <?php echo (get_option('qcld_express_optimize_js_code') == '' ? esc_attr( get_option('qcld_express_optimize_js_code')): esc_attr( 'checked="checked"' )); ?>  />   
                            <i><?php esc_html_e('Minify JavaScript files to increase PageSpeed Score.','express-shop-pro') ?></i>                            
                        </td>
                    </tr>
                    
                    <tr valign="top">
                        <th scope="row"><?php esc_html_e('Minify CSS Files','express-shop-pro') ?></th>
                        <td>
                            <input type="checkbox" name="qcld_express_optimize_css_code" size="100" value="<?php echo (get_option('qcld_express_optimize_css_code')!=''? esc_attr( get_option('qcld_express_optimize_css_code')) : '1' ); ?>" <?php echo (get_option('qcld_express_optimize_css_code') == '' ? esc_attr( get_option('qcld_express_optimize_css_code')): esc_attr( 'checked="checked"' )); ?>  />   
                            <i><?php esc_html_e('Minify CSS files to increase PageSpeed Score.','express-shop-pro') ?></i>                            
                        </td>
                    </tr>
                    
                    <tr valign="top">
                        <th scope="row"><?php esc_html_e('Regenerate minified files','express-shop-pro') ?></th>
                        <td>
                            <button type="button" class="qcld_express_regenerate_css_js button button-primary" size="100" value="1"> <?php esc_html_e('Regenerate','express-shop-pro') ?></button>  
                            <i style="line-height: 30px;"><?php esc_html_e('Do this to manually regenerate the files. Maybe required for debugging or after a plugin update.','express-shop-pro') ?></i>                          
                        </td>
                    </tr>
                    <tr valign="top">
                        <th scope="row"><?php esc_html_e('Enable cache','express-shop-pro') ?></th>
                        <td>
                            <input type="checkbox" name="qcld_express_enable_cache" size="100" value="<?php echo (get_option('qcld_express_enable_cache')!=''? esc_attr( get_option('qcld_express_enable_cache')) : '1' ); ?>" <?php echo (get_option('qcld_express_enable_cache') == '' ? esc_attr( get_option('qcld_express_enable_cache')): esc_attr( 'checked="checked"' )); ?>  />  
                            <i><?php esc_html_e(' This can help improve PageSpeed Score.','express-shop-pro') ?></i>                           
                        </td>
                    </tr>
                    
                    <tr valign="top">
                        <th scope="row"><?php esc_html_e('Cache Time','woo-minimum-acceptable-price') ?></th>
                        <td>
                            <input type="number" name="qcld_express_regenerate_cache_time" style="width:100px" size="100" value="<?php echo (get_option('qcld_express_regenerate_cache_time')!=''?esc_attr( get_option('qcld_express_regenerate_cache_time')):''); ?>"  /> <b><i><?php esc_html_e('seconds','webcam-video-comment') ?></i></b>
                            
                        </td>
                    </tr>
                    
                    <tr valign="top">
                        <th scope="row"><?php esc_html_e('Clear Cache','express-shop-pro') ?></th>
                        <td>
                            <button type="button" class="qcld_express_regenerate_cache button button-danger" size="100" value="1"> <?php esc_html_e('Clear Cache','express-shop-pro') ?></button>  
                            <i style="line-height: 30px;"><?php esc_html_e('Do this to manually clear cache. Maybe required for debugging or after a plugin update.','express-shop-pro') ?></i>                          
                        </td>
                    </tr>
                    
                    
                </table>
            </div>
            
            <?php submit_button(); ?>

        </form>
        
    </div>

    <?php
    }
    
    
}
new Qcld_Express_Performance_Area_Controller();