<?php

defined('ABSPATH') or die("No direct script access!");

if( !function_exists('ot_register_settings') ){
    require_once 'inc/option-tree/ot-loader.php';
}

add_filter( 'ot_show_pages', '__return_false' );
add_filter( 'ot_show_new_layout', '__return_false' );

function qcld_express_pro_remove_ot_menu () {
    remove_submenu_page( 'themes.php', 'ot-theme-options' );
}
add_action( 'admin_init', 'qcld_express_pro_remove_ot_menu' );

add_filter( 'ot_header_version_text', 'qcld_express_pro_developer_text' );

function qcld_express_pro_developer_text(){
    $text = 'Developed by <a href="http://www.quantumcloud.com" target="_blank">Web Design Company - QuantumCloud</a>';

    return $text;
}

/**
 * Hook to register admin pages
 */
add_action( 'init', 'qcld_express_pro_ot_settings_options' );

/**
 * Registers all the required admin pages.
 */

function qcld_express_pro_ot_settings_options() {

    // Only execute in admin & if OT is installed
    if ( is_admin() && function_exists( 'ot_register_settings' ) ) {
        //getting woocommerce product categories
        $terms = get_terms( array(
            'taxonomy'      => 'product_cat',
            'hide_empty'    => false,
        ) );
        $categories=array();
        if(class_exists('WooCommerce')){
            foreach ($terms as $term){
                $categories[] =array(
                    'value'       => $term->term_id,
                    'label'       => __( $term->name, 'qcld_express_cat_'.$term->slug ),
                );
            }
        }
        // Register the pages
        ot_register_settings(
            array(
                array(
                    'id'              => 'qcld_express_options',
                    'pages'           => array(
                        array(
                            'id'              => 'qcld_express_page',
                            'parent_slug'     => 'manage_woocommerce',
                            'page_title'      => 'Express Shop Pro Settings',
                            'menu_title'      => 'Settings',
                            'capability'      => 'edit_theme_options',
                            'menu_slug'       => 'qcld-express-options',
                            'icon_url'        => null,
                            'position'        => 30,
                            'updated_message' => 'Express Shop Options Updated.',
                            'reset_message'   => 'Express Shop Options Reset.',
                            'button_text'     => 'Save Changes',
                            'show_buttons'    => true,
                            'screen_icon'     => 'options-general',
                            'contextual_help' => null,

                            'sections'        => array(
                                array(
                                    'id'          => 'qcld_express_general',
                                    'title'       => __( 'General Settings', 'theme-text-domain' ),
                                ),
                                array(
                                    'id'          => 'qcld_express_css',
                                    'title'       => __( 'Style Settings', 'theme-text-domain' )
                                ),
                                array(
                                    'id'          => 'qcld_express_language',
                                    'title'       => __( 'Language Settings', 'theme-text-domain' ),
                                ),
                                array(
                                    'id'          => 'qcld_express_multi_vendor',
                                    'title'       => __( 'Multi Vendor Settings', 'theme-text-domain' ),
                                ),
                                
                                array(
                                    'id'          => 'help',
                                    'title'       => __( 'Help', 'theme-text-domain' )
                                )
                            ),
                            'settings'        => array(
                                array(
                                    'id'          => 'qcld_express_show_mode',
                                    'label'       => __('Express Shop Products Loading Style'),
                                    'desc'        => __('Set how to display all your products'),
                                    'std'         => 'more',
                                    'type'        => 'radio',
                                    'section'     => 'qcld_express_general',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'min_max_step'=> '',
                                    'class'       => '',
                                    'condition'   => '',
                                    'operator'    => 'and',
                                    'choices'     => array(
                                        array(
                                            'value'       => 'more',
                                            'label'       => __( 'Load More Products', 'qcld-express-load-more' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'scroll',
                                            'label'       => __( 'Infinite Scrolling', 'qcld-express-infite-scroll' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'all',
                                            'label'       => __( 'Show All Products', 'qcld-express-show-all' ),
                                            'src'         => ''
                                        )
                                    )
                                ),
                                array(
                                    'label'       => __('Set products per page for Infinite Scroll and Load More Products'),
                                    'id'          => 'qcld_express_product_per_page',
                                    'type'        => 'text',
                                    'desc'        => __('Products per page for "Infinite Scroll" or "Load More Products" will display as you set above'),
                                    'std'         => '10',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Express Shop cart summary style'),
                                    'id'          => 'qcld_express_cart_mode',
                                    'desc'        => __('Quick cart (button) position. If you select woo instant cart it will enable Ajax add to cart globally.'),
                                    'std'         => 'wooinstants',
                                    'type'        => 'radio',
                                    'section'     => 'qcld_express_general',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'min_max_step'=> '',
                                    'class'       => '',
                                    'condition'   => '',
                                    'operator'    => 'and',
                                    'choices'     => array(
                                        array(
                                            'value'       => 'top',
                                            'label'       => __( 'Top Cart Summary', 'qcld-express-cart-summary' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'leftfloat',
                                            'label'       => __( 'Show Floating Cart Icon on the Left', 'qcld-express-cart-summary' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'rightfloat',
                                            'label'       => __( 'Show Floating Cart Icon on the Right', 'qcld-express-cart-summary' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'wooinstants',
                                            'label'       => __( 'Woo Instant Cart & Checkout Icon on the Right', 'qcld-express-cart-summary' ),
                                            'src'         => ''
                                        ),
                                    )
                                ),
                                array(
                                    'label'       => __('Stop cart expand on product add'),
                                    'id'          => 'qcld_express_floating_quick_cart_stop_expand',
                                    'type'        => 'on-off',
                                    'desc'        => __('Stop floating cart expand on product add'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Show Floating Quick Cart on Express Shop Page Only'),
                                    'id'          => 'qcld_express_floating_quick_cart_single_or_all_page',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable Or Disable To  Show Floating Quick Cart on Express Shop Page Only'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Exclude Categories to show products.'),
                                    'id'          => 'qcld_express_category',
                                    'type'        => 'checkbox',
                                    'desc'        => __('Select categories to execute from product display'),
                                    'std'         => '',
                                    'rows'        => '5',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general',
                                    'choices'     => $categories
                                ),
                                array(
                                    'label'       => __('Template Option'),
                                    'id'          => 'qcld_express_template',
                                    'type'        => 'select',
                                    'desc'        => __('Choose Template for product showcase.'),
                                    'std'         => 'basic',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general',
                                    'choices'     => array(
                                        array(
                                            'value'       => '',
                                            'label'       => __( '-- Choose Template --', 'qcld_express_template' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'basic',
                                            'label'       => __( 'Basic Template (01)','qcld_express_basic' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'animation',
                                            'label'       => __( 'Animated Template (02)', 'qcld_express_animation' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'gradient',
                                            'label'       => __( 'Simple Template (03)', 'qcld_express_animation' ),
                                            'src'         => ''
                                        ),
										array(
                                            'value'       => 'restaurent',
                                            'label'       => __( 'Restaurent Template (04)', 'qcld_express_restaurent' ),
                                            'src'         => ''
                                        ),
										array(
                                            'value'       => 'restaurent-2',
                                            'label'       => __( 'Restaurent Template 2 (05)', 'qcld_express_restaurent-2' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'slope',
                                            'label'       => __( 'Sidebar Template (06)', 'qcld_express_slope' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'catalog',
                                            'label'       => __( 'Catalog Sidebar Template (07)', 'qcld_express_slope' ),
                                            'src'         => ''
                                        ),
                                    )
                                ),
                                array(
                                    'label'       => __('Sort Category by'),
                                    'id'          => 'qcld_express_category_sorting_by',
                                    'desc'        => __('Product sorting by title or date or price'),
                                    'std'         => 'asc',
                                    'type'        => 'radio',
                                    'section'     => 'qcld_express_general',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'min_max_step'=> '',
                                    'class'       => '',
                                    'condition'   => '',
                                    'operator'    => 'and',
                                    'choices'     => array(
                                        array(
                                            'value'       => 'asc',
                                            'label'       => __( 'Title Ascending', 'qcld-express-cart-summary' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'desc',
                                            'label'       => __( 'Title Descending', 'qcld-express-cart-summary' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'menu_order',
                                            'label'       => __( 'Menu Order', 'qcld-express-cart-summary' ),
                                            'src'         => ''
                                        ),
                                    )
                                ),
                                array(
                                    'label'       => __('Sort product by'),
                                    'id'          => 'qcld_express_product_sorting',
                                    'desc'        => __('Product sorting by title or date or price'),
                                    'std'         => 'title',
                                    'type'        => 'radio',
                                    'section'     => 'qcld_express_general',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'min_max_step'=> '',
                                    'class'       => '',
                                    'condition'   => '',
                                    'operator'    => 'and',
                                    'choices'     => array(
                                        array(
                                            'value'       => 'title',
                                            'label'       => __( 'Title', 'qcld-express-cart-summary' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'date',
                                            'label'       => __( 'Date', 'qcld-express-cart-summary' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'meta_value_num',
                                            'label'       => __( 'Price', 'qcld-express-cart-summary' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'menu_order title',
                                            'label'       => __( 'Menu Order', 'qcld-express-cart-summary' ),
                                            'src'         => ''
                                        ),
                                    )
                                ),
                                array(
                                    'label'       => __('Product sorting order'),
                                    'id'          => 'qcld_express_product_asc_desc',
                                    'desc'        => __('Product sorting order by ascending or descending'),
                                    'std'         => 'asc',
                                    'type'        => 'radio',
                                    'section'     => 'qcld_express_general',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'min_max_step'=> '',
                                    'class'       => '',
                                    'condition'   => '',
                                    'operator'    => 'and',
                                    'choices'     => array(
                                        array(
                                            'value'       => 'asc',
                                            'label'       => __( 'Ascending', 'qcld-express-cart-summary' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'desc',
                                            'label'       => __( 'Descending', 'qcld-express-cart-summary' ),
                                            'src'         => ''
                                        ),
                                    )
                                ),
                                array(
                                    'label'       => __('Hide Search Options'),
                                    'id'          => 'qcld_express_hide_search_option',
                                    'type'        => 'on-off',
                                    'desc'        => __('Hide Search Options at header'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Show Category Name Below Title'),
                                    'id'          => 'qcld_express_category_show_below_tite',
                                    'type'        => 'on-off',
                                    'desc'        => __('Show Category Name Below Title'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable Opening and Closing Hours <b style="color:indianred">(Enabling this option will affect what time the shoppers can purchase)</b>'),
                                    'id'          => 'qcld_express_openclose',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable Or Disable to show opening and closing hours at top <br><b style="color:indianred">If this option is enabled, shoppers wont be able to purchase during the Shop closing time you define.</b>'), 
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Opening and Closing Hours (Set id) '),
                                    'id'          => 'qcld_express_openclose_id',
                                    'type'        => 'text',
                                    'desc'        => __('Create your <a href="'.get_admin_url().'edit.php?post_type=op-set" target="_blank">opening hours</a> and copy the Set ID from the right bar <br><b style="color:indianred">You must configure the time and day properly for your shop to work during your working hours.</b>'),
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Set Minimum Price for Checkout Order'),
                                    'id'          => 'qcld_express_min_num_price',
                                    'type'        => 'text',
                                    'desc'        => __('Set minimum total in orders required for checkout'),
                                    'std'         => '20.00',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable category filter'),
                                    'id'          => 'qcld_express_filter',
                                    'type'        => 'on-off',
                                    'desc'        => __('It enabled, category names will show at top for quick filtering'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Fixed Position Category Filters'),
                                    'id'          => 'qcld_express_sticky',
                                    'type'        => 'on-off',
                                    'desc'        => __('Turn on for fixed position category filter buttons'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Top Spacing for Fixed Position Filters'),
                                    'id'          => 'qcld_express_fixed_top_specing',
                                    'type'        => 'text',
                                    'desc'        => __('Set Top Spacing For Fixed Position Category Filters'),
                                    'std'         => '50',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Show categories as dropdown in mobile instead of scroller'),
                                    'id'          => 'qcld_express_show_category_dropdown',
                                    'type'        => 'on-off',
                                    'desc'        => __('Turn on for Show categories as dropdown in mobile instead of scroller'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Show categories as dropdown in catelog sidebar template'),
                                    'id'          => 'qcld_express_show_catelog_dropdown',
                                    'type'        => 'on-off',
                                    'desc'        => __('Turn on for Show categories as dropdown in catelog sidebar template'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable SKU Column'),
                                    'id'          => 'qcld_express_sku',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable to show SKUs '),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable Product Thumbnail column'),
                                    'id'          => 'qcld_express_thumbnail',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable Product Thumbnail button will show the images (thumbnail) column of the products.'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable Title column'),
                                    'id'          => 'qcld_express_title',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable Title button will show the Title column of the products.'),
                                    'std'         => 'on',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable Description Column'),
                                    'id'          => 'qcld_express_description',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable to show product <b style="color:red">excerpts</b> as description'),
                                    'std'         => 'on',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),


                                array(
                                    'label'       => __('How Many Characters to Display from Short Description'),
                                    'id'          => 'qcld_express_short_description_set_character',
                                    'type'        => 'text',
                                    'desc'        => __('Set How Many Characters to Display from Short Description'),
                                    'std'         => '100',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),

                                array(
                                    'label'       => __('Enable Product Price Column'),
                                    'id'          => 'qcld_express_price',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable Product Price button will show the price column of the products'),
                                    'std'         => 'on',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable Action Column'),
                                    'id'          => 'qcld_express_action',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable to show Add to Cart action '),
                                    'std'         => 'on',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable Availability Column'),
                                    'id'          => 'qcld_express_stock',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable Availability button will show the Availability(InStock Or Out of Stock) column of the products.'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Hide Out of Stock Products'),
                                    'id'          => 'qcld_express_out_of_stock',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable for hide out of stock products'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable Tag Column'),
                                    'id'          => 'qcld_express_tag',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable Tag button will show the Tag column of the products.'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable Product Details Button'),
                                    'id'          => 'qcld_express_details_button',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable Product Details button will show the products details modal.'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Disable Add to Cart in Product Details Lightbox'),
                                    'id'          => 'qcld_express_lightbox_add_to_cart_button',
                                    'type'        => 'on-off',
                                    'desc'        => __('Disable Add to Cart in Product Details Lightbox will hide the Add to Cart button.'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Set Show Low Stock Alert Beside Availability'),
                                    'id'          => 'qcld_express_stock_alert',
                                    'type'        => 'text',
                                    'desc'        => __('Show Low Stock will show the Availability with low stock alert in the Availability column of the products.'),
                                    'std'         => '5',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Disable "All" Tab'),
                                    'id'          => 'qcld_express_disable_all_cat_button',
                                    'type'        => 'on-off',
                                    'desc'        => __('Disable All tab from category filters'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable Hot/New/Best Buy tabs'),
                                    'id'          => 'qcld_express_hot_deals_product_tab',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable Hot/New/Best Buy tabs filters'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Hot Deals Tab Filtering According to Category'),
                                    'id'          => 'qcld_express_hot_deals_according_to_cat',
                                    'type'        => 'on-off',
                                    'desc'        => __('Hot deals tab filtering according to category, Default filtering by all category'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Redirect  to the same page after successful add to cart'),
                                    'id'          => 'qcld_express_redurect_page_add_to_cat',
                                    'type'        => 'on-off',
                                    'desc'        => __('Redirect  to the same page after successful add to cart'),
                                    'std'         => 'on',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Show Variable Products as Tooltip'),
                                    'id'          => 'qcld_express_variable_product_show_tooltip',
                                    'type'        => 'on-off',
                                    'desc'        => __('Show Variable Products as Tooltip'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Show sub category according to parent category'),
                                    'id'          => 'qcld_express_category_dropdown_menu',
                                    'type'        => 'on-off',
                                    'desc'        => __('Show Sub category according to parent category'),
                                   // 'desc'        => __('Show Sub category according to parent category for sidebar template'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Audio feature '),
                                    'id'          => 'qcld_express_audio_feature_product',
                                    'type'        => 'on-off',
                                    'desc'        => __('Audio feature add from admin section and display product table.'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Video feature '),
                                    'id'          => 'qcld_express_video_feature_product',
                                    'type'        => 'on-off',
                                    'desc'        => __('Video feature add from admin section and display product table.'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Woo Instant Cart & Checkout plus minus icon added with quantity field.'),
                                    'id'          => 'qcld_express_plus_minus_icon_qty',
                                    'type'        => 'on-off',
                                    'desc'        => __('Woo Instant Cart & Checkout plus minus icon added with quantity field'),
                                    'std'         => 'on',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Scroll to product section when click category for sidebar Template.'),
                                    'id'          => 'qcld_express_scroll_category_clickable',
                                    'type'        => 'on-off',
                                    'desc'        => __('Scroll to product section when click category for sidebar Template'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => 'Express Shop Page Background Color Setting',
                                    'id'          => 'qcld_express_background',
                                    'type'        => 'colorpicker',
                                    'desc'        => __('Background Color will be Express Shop product displaying grid.'),
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_css'
                                ),
                                array(
                                    'label'       => 'Alternative Row Background color Setting',
                                    'id'          => 'qcld_express_altern',
                                    'type'        => 'colorpicker',
                                    'desc'        => __('Alternative Row Background color will be implemented to grid of the products for some templates.'),
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_css'
                                ),
                                array(
                                    'label'       => 'Change Background Color When Active Sidebar',
                                    'id'          => 'qcld_express_active_body_bg',
                                    'type'        => 'colorpicker',
                                    'desc'        => __('When Active Sidebar Background color will be implemented to body for templates.'),
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_css'
                                ),
                                array(
                                    'label'       => 'Active Menu Background color Setting',
                                    'id'          => 'qcld_express_active_menu_bg',
                                    'type'        => 'colorpicker',
                                    'desc'        => __('Active Menu Background color will be implemented to menu for templates.'),
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_css'
                                ),
                                array(
                                    'label'       => 'Active Menu fonts color Setting',
                                    'id'          => 'qcld_express_active_menu_color',
                                    'type'        => 'colorpicker',
                                    'desc'        => __('Active Menu fonts color will be implemented to menu for templates.'),
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_css'
                                ),
                                array(
                                    'label'       => 'Catalog Template Menu fonts color Setting',
                                    'id'          => 'qcld_express_catalog_menu_color',
                                    'type'        => 'colorpicker',
                                    'desc'        => __('Catelog Template Menu fonts color will be implemented to menu for Catalog templates.'),
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_css'
                                ),
                                array(
                                    'label'       => 'Hot Deals Tab Menu Button Fonts Color',
                                    'id'          => 'qcld_express_hot_deals_menu_button_fonts_color',
                                    'type'        => 'colorpicker',
                                    'desc'        => __('Menu Button fonts color will be implemented to menu for Hot Deals Tab.'),
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_css'
                                ),
                                array(
                                    'label'       => 'Hot Deals Tab Menu Button Background Color',
                                    'id'          => 'qcld_express_hot_deals_menu_button_bg_color',
                                    'type'        => 'colorpicker',
                                    'desc'        => __('Menu Button background color will be implemented to menu for Hot Deals Tab.'),
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_css'
                                ),
                                array(
                                    'label'       => 'Hot Deals Tab Menu Background Color',
                                    'id'          => 'qcld_express_hot_deals_menu_bg_color',
                                    'type'        => 'colorpicker',
                                    'desc'        => __('Menu background color will be implemented to menu for Hot Deals Tab.'),
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_css'
                                ),
                                array(
                                    'label'       => 'Restaurent Template Right Top Image',
                                    'id'          => 'qcld_express_top_img',
                                    'type'        => 'upload',
                                    'desc'        => __('Restaurent Template Right Top Image  (Image should be transparent & 250px/200px in size) '),
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_css'
                                ),
                                array(
                                    'label'       => 'Restaurent Template Left Bottom Image',
                                    'id'          => 'qcld_express_bottom_img',
                                    'type'        => 'upload',
                                    'desc'        => __('Restaurent Template Left Bottom Image  (Image should be transparent & 250px/200px in size) '),
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_css'
                                ),
                                array(
                                    'label'       => 'Custom CSS',
                                    'id'          => 'qcld_express_custom_style',
                                    'type'        => 'textarea-simple',
                                    'desc'        => __('Write your custom CSS here.'),
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_css'
                                ),
                                array(
                                    'label'       => __('Help'),
                                    'id'          => 'qcld_express_help',
                                    'type'        => 'Textblock',
                                    'desc'        => '<div>
							<h3>Paste the Following Express Shop Shortcode on Any Page</h3>
							<p><i>Example:</i></p>
                            <div class="ep-shortcode-list">
                                <div> <code> [qcld_express_shop]</code> </div>
                                <div> <code> [qcld_express_shop style="01"]</code> ( ex: style="template number" ) </div>
                                <div> <code> [qcld_express_shop style="01" link_title_to_modal="1"]</code> ( ex: link_title_to_modal="0" | "0" = Disabled or "1" = Enabled ) </div>
                                <div> <code> [qcld_express_shop style="01" category_ids="78,102,39,98"]</code> ( ex: category_ids="Category Id" ) </div>
                                <div> <code> [qcld_express_shop style="01" link_title_to_modal="1" category_ids="78,102,39,98"]</code> ( ex: If you want to show all feature by attribute ) </div>
                                <div> <code> [qcld_express_shop style="01" hot_deals="on"]</code> ( ex: If you want to show Hot/New/Best Buy tabs ) </div>
                            </div>
                            </div>',
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'help'
                                ),
                                array(
                                    'label'       => __('Open Close Hours'),
                                    'id'          => 'qcld_express_helps',
                                    'type'        => 'Textblock',
                                    'desc'        => '<div>
                            <h3>Show Opening and Closing Hours</h3>
                            <p>Enable Opening and Closing Hours from General Settings</p>
                            <h3>Set Id</h3>
                            <p>Opening and Closing Hours post id value insert Opening and Closing Hours (Set id) Field to General settings</p>
                            <h3>Redirect to the same page</h3>
                            <p>Please make sure to Enable AJAX add to cart buttons on Archive for one page shopping experience</p>
                        </div>',
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'help'
                                ),

                                // Express shop pro language all array
                                 array(
                                    'label'       => __('SKU'),
                                    'id'          => 'qcld_express_lang_sku',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for SKU'),
                                    'std'         => 'SKU',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                 array(
                                    'label'       => __('SKU ( Placeholder )'),
                                    'id'          => 'qcld_express_lang_sku_placeholder',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for SKU Placeholder'),
                                    'std'         => 'SKU',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                               
                                array(
                                    'label'       => __('Thumbnail'),
                                    'id'          => 'qcld_express_lang_thumbnail',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Thumbnail'),
                                    'std'         => 'Thumbnail',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                               
                                array(
                                    'label'       => __('Title'),
                                    'id'          => 'qcld_express_lang_title',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Title'),
                                    'std'         => 'Product',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                               
                                array(
                                    'label'       => __('Title ( Placeholder )'),
                                    'id'          => 'qcld_express_lang_title_placeholder',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Title Placeholder'),
                                    'std'         => 'Search',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                               
                                array(
                                    'label'       => __('Description'),
                                    'id'          => 'qcld_express_lang_desc',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Description'),
                                    'std'         => 'Description',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                               
                                array(
                                    'label'       => __('Availability'),
                                    'id'          => 'qcld_express_lang_availability',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Availability'),
                                    'std'         => 'Availability',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Price'),
                                    'id'          => 'qcld_express_lang_price',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Price'),
                                    'std'         => 'Price',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('All'),
                                    'id'          => 'qcld_express_lang_all_category',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for All Category'),
                                    'std'         => 'All',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                               
                                array(
                                    'label'       => __('Action'),
                                    'id'          => 'qcld_express_lang_action',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Action'),
                                    'std'         => 'Action',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                               
                               
                                array(
                                    'label'       => __('Search'),
                                    'id'          => 'qcld_express_lang_search',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Search'),
                                    'std'         => 'Search',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Cart Summary'),
                                    'id'          => 'qcld_express_lang_cart_summary',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Cart Summary'),
                                    'std'         => 'Cart Summary',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Edit on Cart'),
                                    'id'          => 'qcld_express_lang_edit_on_cart',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Edit on Cart'),
                                    'std'         => 'Edit on Cart',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Checkout'),
                                    'id'          => 'qcld_express_lang_checkout',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Checkout'),
                                    'std'         => 'Checkout',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('No products in the cart'),
                                    'id'          => 'qcld_express_lang_no_products',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for No products in the cart'),
                                    'std'         => 'No products in the cart',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Minimum Price Alert Header 1'),
                                    'id'          => 'qcld_express_lang_cart_minimum_alert_1',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Cart Summary'),
                                    'std'         => ' is the minimum order value. Continue shopping.',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Minimum Price Alert Header 2'),
                                    'id'          => 'qcld_express_lang_cart_minimum_alert_2',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Cart Summary'),
                                    'std'         => 'Current total order in the cart',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('We are Closed Now'),
                                    'id'          => 'qcld_express_closed_now_lang',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Cart Summary'),
                                    'std'         => 'We are Closed Now',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Alert'),
                                    'id'          => 'qcld_express_lang_alert_out_of_stock_alert',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Alert'),
                                    'std'         => 'Alert',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Out of Stock Alert'),
                                    'id'          => 'qcld_express_lang_alert_out_of_stock',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Cart Summary'),
                                    'std'         => 'The Product is Currently Out of Stock.',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Quantity'),
                                    'id'          => 'qcld_express_lang_quantity',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Quantity'),
                                    'std'         => 'Quantity',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('items'),
                                    'id'          => 'qcld_express_lang_items',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for cart items'),
                                    'std'         => 'items',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Add to Cart'),
                                    'id'          => 'qcld_express_lang_add_to_cart',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Add to Cart button'),
                                    'std'         => 'Add to Cart',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Total'),
                                    'id'          => 'qcld_express_lang_cart_total',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for cart Total'),
                                    'std'         => 'Total',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Load More'),
                                    'id'          => 'qcld_express_lang_load_more',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Load More'),
                                    'std'         => 'Load More',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Scrolling'),
                                    'id'          => 'qcld_express_lang_load_more_scrolling',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Scrolling'),
                                    'std'         => 'Scrolling',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Hot'),
                                    'id'          => 'qcld_express_lang_hot_deals_hot',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Hot'),
                                    'std'         => 'Hot',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('New'),
                                    'id'          => 'qcld_express_lang_hot_deals_new',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for New'),
                                    'std'         => 'New',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Best Buy'),
                                    'id'          => 'qcld_express_lang_hot_deals_best_buy',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Best Buy'),
                                    'std'         => 'Best Buy',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Featured'),
                                    'id'          => 'qcld_express_lang_hot_deals_featured',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Featured'),
                                    'std'         => 'Featured',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('In Stock'),
                                    'id'          => 'qcld_express_lang_in_stock',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for In Stock'),
                                    'std'         => 'In Stock',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Out of Stock'),
                                    'id'          => 'qcld_express_lang_out_of_stock',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Out of Stock'),
                                    'std'         => 'Out of Stock',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('From'),
                                    'id'          => 'qcld_express_lang_from',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for From'),
                                    'std'         => 'From',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('To'),
                                    'id'          => 'qcld_express_lang_to',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for To'),
                                    'std'         => 'To',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Category'),
                                    'id'          => 'qcld_express_lang_category',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Category'),
                                    'std'         => 'Category',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Tag'),
                                    'id'          => 'qcld_express_tag_lang',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Tag'),
                                    'std'         => 'Tag',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('We\'re currently open.'),
                                    'id'          => 'qcld_express_currently_open_lang',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for We\'re currently open.'),
                                    'std'         => 'We\'re currently open.',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('We\'re currently closed.'),
                                    'id'          => 'qcld_express_currently_closed_lang',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for We\'re currently closed.'),
                                    'std'         => 'We\'re currently closed.',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Opening Hours today'),
                                    'id'          => 'qcld_express_opening_hours_today_lang',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Opening Hours today'),
                                    'std'         => 'Opening Hours today',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('We\'re open again on'),
                                    'id'          => 'qcld_express_opening_again_on_lang',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for We\'re open again on'),
                                    'std'         => 'We\'re open again on',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('from'),
                                    'id'          => 'qcld_express_opening_again_from_lang',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for from'),
                                    'std'         => 'from',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('to'),
                                    'id'          => 'qcld_express_opening_again_to_lang',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for to'),
                                    'std'         => 'to',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Dokan Multi Vendor'),
                                    'id'          => 'qcld_express_multi_vendor_dokan_enable',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable for Dokan Multi Vendor Plugin use Express shop Template'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_multi_vendor'
                                ),

                                array(
                                    'label'       => __('Template Option'),
                                    'id'          => 'qcld_express_multi_vendor_template',
                                    'type'        => 'select',
                                    'desc'        => __('Choose Template for product showcase.'),
                                    'std'         => '01',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_multi_vendor',
                                    'choices'     => array(
                                        array(
                                            'value'       => '',
                                            'label'       => __( '-- Choose Template --', 'qcld_express_template' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => '01',
                                            'label'       => __( 'Basic Template (01)','qcld_express_basic' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => '02',
                                            'label'       => __( 'Animated Template (02)', 'qcld_express_animation' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => '03',
                                            'label'       => __( 'Simple Template (03)', 'qcld_express_animation' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => '04',
                                            'label'       => __( 'Restaurent Template (04)', 'qcld_express_restaurent' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => '05',
                                            'label'       => __( 'Restaurent Template 2 (05)', 'qcld_express_restaurent-2' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => '06',
                                            'label'       => __( 'Sidebar Template (06)', 'qcld_express_slope' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => '07',
                                            'label'       => __( 'Catalog Sidebar Template (07)', 'qcld_express_slope' ),
                                            'src'         => ''
                                        ),
                                    )
                                ),
                                array(
                                    'label'       => __('Link Title Modal'),
                                    'id'          => 'qcld_express_link_title_modal_mlti_v',
                                    'type'        => 'on-off',
                                    'desc'        => __('Show modal when click Title'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_multi_vendor'
                                ),
                                array(
                                    'label'       => __('Category ids'),
                                    'id'          => 'qcld_express_multi_vendor_cat_ids',
                                    'type'        => 'text',
                                    'desc'        => 'Category id use with comma separate value. <br>Ex: 78,95,98',
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_multi_vendor'
                                ),
                               

                            )
                        )
                    )
                )
            )
        );
    }
}